==> querydsl-parser-0.1-sources.jar: foundation/jpa/querydsl/StateDouble2.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateDouble2 extends StackState<java.lang.Double, State> {

// NoStack:
// Stack:
    public StateDouble2(foundation.jpa.querydsl.QueryFactory factory, java.lang.Double node, State prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitEqual(foundation.rpg.common.symbols.Equal symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitEqual(symbol);
    }

    @Override
    public State visitIn(foundation.rpg.common.symbols.In symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitIn(symbol);
    }

    @Override
    public State visitTilda(foundation.rpg.common.symbols.Tilda symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitTilda(symbol);
    }

    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitAnd(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        State stack1 = this.getPrev();
        return Arrays.asList(this.getNode());
    }

}

==> querydsl-parser-0.2-sources.jar: foundation/jpa/querydsl/StateDouble2.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateDouble2 extends StackState<java.lang.Double, State> {

// NoStack:
// Stack:
    public StateDouble2(foundation.jpa.querydsl.QueryFactory factory, java.lang.Double node, State prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitEqual(foundation.rpg.common.symbols.Equal symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitEqual(symbol);
    }

    @Override
    public State visitIs(foundation.rpg.common.symbols.Is symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitIs(symbol);
    }

    @Override
    public State visitNot(foundation.rpg.common.symbols.Not symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitNot(symbol);
    }

    @Override
    public State visitIn(foundation.rpg.common.symbols.In symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitIn(symbol);
    }

    @Override
    public State visitTilda(foundation.rpg.common.symbols.Tilda symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitTilda(symbol);
    }

    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        State stack1 = this.getPrev();
        return stack1.visitExpression(getFactory().is(this.getNode())).visitAnd(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        State stack1 = this.getPrev();
        return Arrays.asList(this.getNode());
    }

}
